# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63ommon.proto\x12\x07\x63tplite\"\x8a\x01\n\x0b\x41uthRequest\x12\x11\n\tbroker_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\t\x12\x11\n\tauth_code\x18\x05 \x01(\t\x12\r\n\x05token\x18\x06 \x01(\t\x12\x13\n\x0binvestor_id\x18\x07 \x01(\t\"#\n\rErrorResponse\x12\x12\n\nerror_code\x18\x01 \x01(\x05\"\x07\n\x05\x45mpty*\x8b\x03\n\tErrorCode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x13\n\x0fINVALID_SESSION\x10\x01\x12\x16\n\x12INVALID_INSTRUMENT\x10\x02\x12\x13\n\x0fINVALID_REQUEST\x10\x03\x12\x11\n\rNOT_LOGGED_IN\x10\x04\x12\x15\n\x11\x43ONNECTION_FAILED\x10\x05\x12\x0b\n\x07TIMEOUT\x10\x06\x12\x16\n\x12INSUFFICIENT_FUNDS\x10\x07\x12\x11\n\rINVALID_PRICE\x10\x08\x12\x12\n\x0eINVALID_VOLUME\x10\t\x12\x12\n\x0eORDER_REJECTED\x10\n\x12\x11\n\rMARKET_CLOSED\x10\x0b\x12\x16\n\x12POSITION_NOT_FOUND\x10\x0c\x12\x13\n\x0fORDER_NOT_FOUND\x10\r\x12\x13\n\x0f\x44UPLICATE_ORDER\x10\x0e\x12\x15\n\x11INVALID_DIRECTION\x10\x0f\x12\x12\n\x0eINVALID_OFFSET\x10\x10\x12\x12\n\x0eINTERNAL_ERROR\x10\x63\x12\x11\n\rUNKNOWN_ERROR\x10\x64\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ERRORCODE']._serialized_start=213
  _globals['_ERRORCODE']._serialized_end=608
  _globals['_AUTHREQUEST']._serialized_start=26
  _globals['_AUTHREQUEST']._serialized_end=164
  _globals['_ERRORRESPONSE']._serialized_start=166
  _globals['_ERRORRESPONSE']._serialized_end=201
  _globals['_EMPTY']._serialized_start=203
  _globals['_EMPTY']._serialized_end=210
# @@protoc_insertion_point(module_scope)
