# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: auth.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x07\x63tplite\x1a\x0c\x63ommon.proto\"|\n\x0cLoginRequest\x12\x11\n\tbroker_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\t\x12\x11\n\tauth_code\x18\x05 \x01(\t\x12\x13\n\x0binvestor_id\x18\x06 \x01(\t\"q\n\rLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x12\n\nerror_code\x18\x03 \x01(\x05\x12\x15\n\rerror_message\x18\x04 \x01(\t\x12\x12\n\nexpires_at\x18\x05 \x01(\x03\"\x1e\n\rLogoutRequest\x12\r\n\x05token\x18\x01 \x01(\t\";\n\x0eLogoutResponse\x12\x12\n\nerror_code\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"$\n\x13RefreshTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t\"d\n\x14RefreshTokenResponse\x12\r\n\x05token\x18\x01 \x01(\t\x12\x12\n\nexpires_at\x18\x02 \x01(\x03\x12\x12\n\nerror_code\x18\x03 \x01(\x05\x12\x15\n\rerror_message\x18\x04 \x01(\t2\xcd\x01\n\x0b\x41uthService\x12\x36\n\x05Login\x12\x15.ctplite.LoginRequest\x1a\x16.ctplite.LoginResponse\x12\x39\n\x06Logout\x12\x16.ctplite.LogoutRequest\x1a\x17.ctplite.LogoutResponse\x12K\n\x0cRefreshToken\x12\x1c.ctplite.RefreshTokenRequest\x1a\x1d.ctplite.RefreshTokenResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LOGINREQUEST']._serialized_start=37
  _globals['_LOGINREQUEST']._serialized_end=161
  _globals['_LOGINRESPONSE']._serialized_start=163
  _globals['_LOGINRESPONSE']._serialized_end=276
  _globals['_LOGOUTREQUEST']._serialized_start=278
  _globals['_LOGOUTREQUEST']._serialized_end=308
  _globals['_LOGOUTRESPONSE']._serialized_start=310
  _globals['_LOGOUTRESPONSE']._serialized_end=369
  _globals['_REFRESHTOKENREQUEST']._serialized_start=371
  _globals['_REFRESHTOKENREQUEST']._serialized_end=407
  _globals['_REFRESHTOKENRESPONSE']._serialized_start=409
  _globals['_REFRESHTOKENRESPONSE']._serialized_end=509
  _globals['_AUTHSERVICE']._serialized_start=512
  _globals['_AUTHSERVICE']._serialized_end=717
# @@protoc_insertion_point(module_scope)
