# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: market_data.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'market_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11market_data.proto\x12\x07\x63tplite\x1a\x0c\x63ommon.proto\"\xaf\x03\n\x08TickData\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x12\n\ntrade_date\x18\x03 \x01(\t\x12\x13\n\x0b\x61\x63tion_date\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\x12\x12\n\nlast_price\x18\x06 \x01(\x01\x12\x16\n\x0epre_settlement\x18\x07 \x01(\x01\x12\x11\n\tpre_close\x18\x08 \x01(\x01\x12\x19\n\x11pre_open_interest\x18\t \x01(\x01\x12\x0c\n\x04open\x18\n \x01(\x01\x12\x0c\n\x04high\x18\x0b \x01(\x01\x12\x0b\n\x03low\x18\x0c \x01(\x01\x12\x0e\n\x06volume\x18\r \x01(\x03\x12\x10\n\x08turnover\x18\x0e \x01(\x01\x12\x15\n\ropen_interest\x18\x0f \x01(\x01\x12\x10\n\x08up_limit\x18\x10 \x01(\x01\x12\x12\n\ndown_limit\x18\x11 \x01(\x01\x12\x11\n\tavg_price\x18\x12 \x01(\x01\x12\x12\n\nbid1_price\x18\x13 \x01(\x01\x12\x13\n\x0b\x62id1_volume\x18\x14 \x01(\x05\x12\x12\n\nask1_price\x18\x15 \x01(\x01\x12\x13\n\x0b\x61sk1_volume\x18\x16 \x01(\x05\"\\\n\x10SubscribeRequest\x12\x0f\n\x07symbols\x18\x01 \x03(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.ctplite.AuthRequest\x12\x13\n\x0bkafka_topic\x18\x03 \x01(\t\"G\n\x10MarketDataStream\x12\x1f\n\x04tick\x18\x01 \x01(\x0b\x32\x11.ctplite.TickData\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"Z\n\x11SubscribeResponse\x12\x12\n\nerror_code\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x1a\n\x12subscribed_symbols\x18\x03 \x03(\t\"I\n\x12UnsubscribeRequest\x12\x0f\n\x07symbols\x18\x01 \x03(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.ctplite.AuthRequest\"^\n\x13UnsubscribeResponse\x12\x12\n\nerror_code\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x1c\n\x14unsubscribed_symbols\x18\x03 \x03(\t2\x88\x02\n\x11MarketDataService\x12M\n\x13SubscribeMarketData\x12\x19.ctplite.SubscribeRequest\x1a\x19.ctplite.MarketDataStream0\x01\x12P\n\x17SubscribeMarketDataOnce\x12\x19.ctplite.SubscribeRequest\x1a\x1a.ctplite.SubscribeResponse\x12R\n\x15UnsubscribeMarketData\x12\x1b.ctplite.UnsubscribeRequest\x1a\x1c.ctplite.UnsubscribeResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'market_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TICKDATA']._serialized_start=45
  _globals['_TICKDATA']._serialized_end=476
  _globals['_SUBSCRIBEREQUEST']._serialized_start=478
  _globals['_SUBSCRIBEREQUEST']._serialized_end=570
  _globals['_MARKETDATASTREAM']._serialized_start=572
  _globals['_MARKETDATASTREAM']._serialized_end=643
  _globals['_SUBSCRIBERESPONSE']._serialized_start=645
  _globals['_SUBSCRIBERESPONSE']._serialized_end=735
  _globals['_UNSUBSCRIBEREQUEST']._serialized_start=737
  _globals['_UNSUBSCRIBEREQUEST']._serialized_end=810
  _globals['_UNSUBSCRIBERESPONSE']._serialized_start=812
  _globals['_UNSUBSCRIBERESPONSE']._serialized_end=906
  _globals['_MARKETDATASERVICE']._serialized_start=909
  _globals['_MARKETDATASERVICE']._serialized_end=1173
# @@protoc_insertion_point(module_scope)
