# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: trading.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'trading.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rtrading.proto\x12\x07\x63tplite\x1a\x0c\x63ommon.proto\"\xe3\x01\n\x0cOrderRequest\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12%\n\tdirection\x18\x03 \x01(\x0e\x32\x12.ctplite.Direction\x12\x1f\n\x06offset\x18\x04 \x01(\x0e\x32\x0f.ctplite.Offset\x12\r\n\x05price\x18\x05 \x01(\x01\x12\x0e\n\x06volume\x18\x06 \x01(\x05\x12&\n\norder_type\x18\x07 \x01(\x0e\x32\x12.ctplite.OrderType\x12\"\n\x04\x61uth\x18\x08 \x01(\x0b\x32\x14.ctplite.AuthRequest\"g\n\rCancelRequest\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.ctplite.AuthRequest\"5\n\rOrderResponse\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"U\n\rPositionQuery\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.ctplite.AuthRequest\"\x90\x01\n\x0cPositionData\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12%\n\tdirection\x18\x03 \x01(\x0e\x32\x12.ctplite.Direction\x12\x10\n\x08position\x18\x04 \x01(\x05\x12\x15\n\rposition_cost\x18\x05 \x01(\x01\x12\x0e\n\x06profit\x18\x06 \x01(\x01\"P\n\x10PositionResponse\x12(\n\tpositions\x18\x01 \x03(\x0b\x32\x15.ctplite.PositionData\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"\xb0\x01\n\x11OrderStatusUpdate\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12$\n\x06status\x18\x02 \x01(\x0e\x32\x14.ctplite.OrderStatus\x12\x15\n\rfilled_volume\x18\x03 \x01(\x05\x12\x11\n\tavg_price\x18\x04 \x01(\x01\x12\x0e\n\x06symbol\x18\x05 \x01(\t\x12\x12\n\nerror_code\x18\x06 \x01(\x05\x12\x15\n\rerror_message\x18\x07 \x01(\t\"9\n\x13TradingAccountQuery\x12\"\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x14.ctplite.AuthRequest\"\xe5\x03\n\x12TradingAccountData\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\x01\x12\x11\n\tavailable\x18\x03 \x01(\x01\x12\x15\n\rfrozen_margin\x18\x04 \x01(\x01\x12\x13\n\x0b\x66rozen_cash\x18\x05 \x01(\x01\x12\x19\n\x11\x66rozen_commission\x18\x06 \x01(\x01\x12\x13\n\x0b\x63urr_margin\x18\x07 \x01(\x01\x12\x14\n\x0c\x63lose_profit\x18\x08 \x01(\x01\x12\x17\n\x0fposition_profit\x18\t \x01(\x01\x12\x12\n\ncommission\x18\n \x01(\x01\x12\x0f\n\x07\x64\x65posit\x18\x0b \x01(\x01\x12\x10\n\x08withdraw\x18\x0c \x01(\x01\x12\x13\n\x0bpre_balance\x18\r \x01(\x01\x12\x12\n\npre_margin\x18\x0e \x01(\x01\x12\x12\n\npre_credit\x18\x0f \x01(\x01\x12\x13\n\x0bpre_deposit\x18\x10 \x01(\x01\x12\x10\n\x08interest\x18\x11 \x01(\x01\x12\x15\n\rinterest_base\x18\x12 \x01(\x01\x12\x17\n\x0f\x65xchange_margin\x18\x13 \x01(\x01\x12\x17\n\x0f\x64\x65livery_margin\x18\x14 \x01(\x01\x12\x0f\n\x07reserve\x18\x15 \x01(\x01\x12\x17\n\x0freserve_balance\x18\x16 \x01(\x01\"Z\n\x16TradingAccountResponse\x12,\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1b.ctplite.TradingAccountData\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"h\n\nOrderQuery\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x14\n\x0corder_sys_id\x18\x03 \x01(\t\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.ctplite.AuthRequest\"\xb7\x02\n\tOrderData\x12\x10\n\x08order_id\x18\x01 \x01(\t\x12\x14\n\x0corder_sys_id\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\x12%\n\tdirection\x18\x05 \x01(\x0e\x32\x12.ctplite.Direction\x12\x1f\n\x06offset\x18\x06 \x01(\x0e\x32\x0f.ctplite.Offset\x12\r\n\x05price\x18\x07 \x01(\x01\x12\x0e\n\x06volume\x18\x08 \x01(\x05\x12\x15\n\rtraded_volume\x18\t \x01(\x05\x12$\n\x06status\x18\n \x01(\x0e\x32\x14.ctplite.OrderStatus\x12\x13\n\x0binsert_time\x18\x0b \x01(\t\x12\x13\n\x0bupdate_time\x18\x0c \x01(\t\x12\x12\n\nstatus_msg\x18\r \x01(\t\"L\n\x12OrderQueryResponse\x12\"\n\x06orders\x18\x01 \x03(\x0b\x32\x12.ctplite.OrderData\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"d\n\nTradeQuery\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x10\n\x08trade_id\x18\x03 \x01(\t\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.ctplite.AuthRequest\"\xe2\x01\n\tTradeData\x12\x10\n\x08trade_id\x18\x01 \x01(\t\x12\x10\n\x08order_id\x18\x02 \x01(\t\x12\x14\n\x0corder_sys_id\x18\x03 \x01(\t\x12\x0e\n\x06symbol\x18\x04 \x01(\t\x12\x10\n\x08\x65xchange\x18\x05 \x01(\t\x12%\n\tdirection\x18\x06 \x01(\x0e\x32\x12.ctplite.Direction\x12\x1f\n\x06offset\x18\x07 \x01(\x0e\x32\x0f.ctplite.Offset\x12\r\n\x05price\x18\x08 \x01(\x01\x12\x0e\n\x06volume\x18\t \x01(\x05\x12\x12\n\ntrade_time\x18\n \x01(\t\"L\n\x12TradeQueryResponse\x12\"\n\x06trades\x18\x01 \x03(\x0b\x32\x12.ctplite.TradeData\x12\x12\n\nerror_code\x18\x02 \x01(\x05\">\n\x18SettlementConfirmRequest\x12\"\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x14.ctplite.AuthRequest\"@\n\x19SettlementConfirmResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"W\n\x0fInstrumentQuery\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.ctplite.AuthRequest\"\xcf\x04\n\x0eInstrumentData\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nproduct_id\x18\x04 \x01(\t\x12\x15\n\rproduct_class\x18\x05 \x01(\x05\x12\x15\n\rdelivery_year\x18\x06 \x01(\x05\x12\x16\n\x0e\x64\x65livery_month\x18\x07 \x01(\x05\x12\x1f\n\x17max_market_order_volume\x18\x08 \x01(\x05\x12\x1f\n\x17min_market_order_volume\x18\t \x01(\x05\x12\x1e\n\x16max_limit_order_volume\x18\n \x01(\x05\x12\x1e\n\x16min_limit_order_volume\x18\x0b \x01(\x05\x12\x17\n\x0fvolume_multiple\x18\x0c \x01(\x05\x12\x12\n\nprice_tick\x18\r \x01(\x01\x12\x13\n\x0b\x63reate_date\x18\x0e \x01(\t\x12\x11\n\topen_date\x18\x0f \x01(\t\x12\x13\n\x0b\x65xpire_date\x18\x10 \x01(\t\x12\x18\n\x10start_deliv_date\x18\x11 \x01(\t\x12\x16\n\x0e\x65nd_deliv_date\x18\x12 \x01(\t\x12\x17\n\x0finst_life_phase\x18\x13 \x01(\x05\x12\x12\n\nis_trading\x18\x14 \x01(\x05\x12\x15\n\rposition_type\x18\x15 \x01(\t\x12\x1a\n\x12position_date_type\x18\x16 \x01(\t\x12\x19\n\x11long_margin_ratio\x18\x17 \x01(\x01\x12\x1a\n\x12short_margin_ratio\x18\x18 \x01(\x01\"[\n\x17InstrumentQueryResponse\x12,\n\x0binstruments\x18\x01 \x03(\x0b\x32\x17.ctplite.InstrumentData\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"u\n\x19InstrumentMarginRateQuery\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x12\n\nhedge_flag\x18\x03 \x01(\t\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.ctplite.AuthRequest\"\xb9\x02\n\x18InstrumentMarginRateData\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x11\n\tbroker_id\x18\x03 \x01(\t\x12\x13\n\x0binvestor_id\x18\x04 \x01(\t\x12\x12\n\nhedge_flag\x18\x05 \x01(\t\x12\"\n\x1along_margin_ratio_by_money\x18\x06 \x01(\x01\x12#\n\x1blong_margin_ratio_by_volume\x18\x07 \x01(\x01\x12#\n\x1bshort_margin_ratio_by_money\x18\x08 \x01(\x01\x12$\n\x1cshort_margin_ratio_by_volume\x18\t \x01(\x01\x12\x13\n\x0bis_relative\x18\n \x01(\x08\x12\x16\n\x0einvest_unit_id\x18\x0b \x01(\t\"k\n\x1cInstrumentMarginRateResponse\x12\x37\n\x0cmargin_rates\x18\x01 \x03(\x0b\x32!.ctplite.InstrumentMarginRateData\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"e\n\x1dInstrumentCommissionRateQuery\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.ctplite.AuthRequest\"\xd3\x02\n\x1cInstrumentCommissionRateData\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x11\n\tbroker_id\x18\x03 \x01(\t\x12\x13\n\x0binvestor_id\x18\x04 \x01(\t\x12\x1b\n\x13open_ratio_by_money\x18\x05 \x01(\x01\x12\x1c\n\x14open_ratio_by_volume\x18\x06 \x01(\x01\x12\x1c\n\x14\x63lose_ratio_by_money\x18\x07 \x01(\x01\x12\x1d\n\x15\x63lose_ratio_by_volume\x18\x08 \x01(\x01\x12\"\n\x1a\x63lose_today_ratio_by_money\x18\t \x01(\x01\x12#\n\x1b\x63lose_today_ratio_by_volume\x18\n \x01(\x01\x12\x10\n\x08\x62iz_type\x18\x0b \x01(\t\x12\x16\n\x0einvest_unit_id\x18\x0c \x01(\t\"w\n InstrumentCommissionRateResponse\x12?\n\x10\x63ommission_rates\x18\x01 \x03(\x0b\x32%.ctplite.InstrumentCommissionRateData\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"N\n\x13SettlementInfoQuery\x12\x13\n\x0btrading_day\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.ctplite.AuthRequest\"\xb7\x01\n\x12SettlementInfoData\x12\x13\n\x0btrading_day\x18\x01 \x01(\t\x12\x15\n\rsettlement_id\x18\x02 \x01(\x05\x12\x11\n\tbroker_id\x18\x03 \x01(\t\x12\x13\n\x0binvestor_id\x18\x04 \x01(\t\x12\x13\n\x0bsequence_no\x18\x05 \x01(\x05\x12\x0f\n\x07\x63ontent\x18\x06 \x01(\t\x12\x12\n\naccount_id\x18\x07 \x01(\t\x12\x13\n\x0b\x63urrency_id\x18\x08 \x01(\t\"c\n\x16SettlementInfoResponse\x12\x35\n\x10settlement_infos\x18\x01 \x03(\x0b\x32\x1b.ctplite.SettlementInfoData\x12\x12\n\nerror_code\x18\x02 \x01(\x05\":\n\x14TradingLogoutRequest\x12\"\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x14.ctplite.AuthRequest\"<\n\x15TradingLogoutResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"\xb7\x01\n\x13MaxOrderVolumeQuery\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12%\n\tdirection\x18\x03 \x01(\x0e\x32\x12.ctplite.Direction\x12\x1f\n\x06offset\x18\x04 \x01(\x0e\x32\x0f.ctplite.Offset\x12\x12\n\nhedge_flag\x18\x05 \x01(\t\x12\"\n\x04\x61uth\x18\x06 \x01(\x0b\x32\x14.ctplite.AuthRequest\"\xe6\x01\n\x12MaxOrderVolumeData\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08\x65xchange\x18\x02 \x01(\t\x12\x11\n\tbroker_id\x18\x03 \x01(\t\x12\x13\n\x0binvestor_id\x18\x04 \x01(\t\x12%\n\tdirection\x18\x05 \x01(\x0e\x32\x12.ctplite.Direction\x12\x1f\n\x06offset\x18\x06 \x01(\x0e\x32\x0f.ctplite.Offset\x12\x12\n\nhedge_flag\x18\x07 \x01(\t\x12\x12\n\nmax_volume\x18\x08 \x01(\x05\x12\x16\n\x0einvest_unit_id\x18\t \x01(\t\"c\n\x16MaxOrderVolumeResponse\x12\x35\n\x10max_order_volume\x18\x01 \x01(\x0b\x32\x1b.ctplite.MaxOrderVolumeData\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"H\n\rExchangeQuery\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.ctplite.AuthRequest\"U\n\x0c\x45xchangeData\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x15\n\rexchange_name\x18\x02 \x01(\t\x12\x19\n\x11\x65xchange_property\x18\x03 \x01(\t\"P\n\x10\x45xchangeResponse\x12(\n\texchanges\x18\x01 \x03(\x0b\x32\x15.ctplite.ExchangeData\x12\x12\n\nerror_code\x18\x02 \x01(\x05\"3\n\rInvestorQuery\x12\"\n\x04\x61uth\x18\x01 \x01(\x0b\x32\x14.ctplite.AuthRequest\"\xde\x02\n\x0cInvestorData\x12\x13\n\x0binvestor_id\x18\x01 \x01(\t\x12\x11\n\tbroker_id\x18\x02 \x01(\t\x12\x19\n\x11investor_group_id\x18\x03 \x01(\t\x12\x15\n\rinvestor_name\x18\x04 \x01(\t\x12\x1c\n\x14identified_card_type\x18\x05 \x01(\t\x12\x1a\n\x12identified_card_no\x18\x06 \x01(\t\x12\x11\n\tis_active\x18\x07 \x01(\x08\x12\x11\n\ttelephone\x18\x08 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\t \x01(\t\x12\x11\n\topen_date\x18\n \x01(\t\x12\x0e\n\x06mobile\x18\x0b \x01(\t\x12\x15\n\rcomm_model_id\x18\x0c \x01(\t\x12\x17\n\x0fmargin_model_id\x18\r \x01(\t\x12\x15\n\ris_order_freq\x18\x0e \x01(\x08\x12\x19\n\x11is_open_vol_limit\x18\x0f \x01(\x08\"O\n\x10InvestorResponse\x12\'\n\x08investor\x18\x01 \x01(\x0b\x32\x15.ctplite.InvestorData\x12\x12\n\nerror_code\x18\x02 \x01(\x05*\x1e\n\tDirection\x12\x07\n\x03\x42UY\x10\x00\x12\x08\n\x04SELL\x10\x01*C\n\x06Offset\x12\x08\n\x04OPEN\x10\x00\x12\t\n\x05\x43LOSE\x10\x01\x12\x0f\n\x0b\x43LOSE_TODAY\x10\x02\x12\x13\n\x0f\x43LOSE_YESTERDAY\x10\x03*4\n\tOrderType\x12\t\n\x05LIMIT\x10\x00\x12\n\n\x06MARKET\x10\x01\x12\x07\n\x03\x46\x41K\x10\x02\x12\x07\n\x03\x46OK\x10\x03*i\n\x0bOrderStatus\x12\x0e\n\nSUBMITTING\x10\x00\x12\r\n\tSUBMITTED\x10\x01\x12\x12\n\x0ePARTIAL_FILLED\x10\x02\x12\n\n\x06\x46ILLED\x10\x03\x12\r\n\tCANCELLED\x10\x04\x12\x0c\n\x08REJECTED\x10\x05\x32\xfe\t\n\x0eTradingService\x12;\n\nPlaceOrder\x12\x15.ctplite.OrderRequest\x1a\x16.ctplite.OrderResponse\x12=\n\x0b\x43\x61ncelOrder\x12\x16.ctplite.CancelRequest\x1a\x16.ctplite.OrderResponse\x12\x42\n\rQueryPosition\x12\x16.ctplite.PositionQuery\x1a\x19.ctplite.PositionResponse\x12G\n\x11StreamOrderStatus\x12\x14.ctplite.AuthRequest\x1a\x1a.ctplite.OrderStatusUpdate0\x01\x12T\n\x13QueryTradingAccount\x12\x1c.ctplite.TradingAccountQuery\x1a\x1f.ctplite.TradingAccountResponse\x12>\n\nQueryOrder\x12\x13.ctplite.OrderQuery\x1a\x1b.ctplite.OrderQueryResponse\x12>\n\nQueryTrade\x12\x13.ctplite.TradeQuery\x1a\x1b.ctplite.TradeQueryResponse\x12^\n\x15\x43onfirmSettlementInfo\x12!.ctplite.SettlementConfirmRequest\x1a\".ctplite.SettlementConfirmResponse\x12M\n\x0fQueryInstrument\x12\x18.ctplite.InstrumentQuery\x1a .ctplite.InstrumentQueryResponse\x12\x66\n\x19QueryInstrumentMarginRate\x12\".ctplite.InstrumentMarginRateQuery\x1a%.ctplite.InstrumentMarginRateResponse\x12r\n\x1dQueryInstrumentCommissionRate\x12&.ctplite.InstrumentCommissionRateQuery\x1a).ctplite.InstrumentCommissionRateResponse\x12T\n\x13QuerySettlementInfo\x12\x1c.ctplite.SettlementInfoQuery\x1a\x1f.ctplite.SettlementInfoResponse\x12N\n\rTradingLogout\x12\x1d.ctplite.TradingLogoutRequest\x1a\x1e.ctplite.TradingLogoutResponse\x12T\n\x13QueryMaxOrderVolume\x12\x1c.ctplite.MaxOrderVolumeQuery\x1a\x1f.ctplite.MaxOrderVolumeResponse\x12\x42\n\rQueryExchange\x12\x16.ctplite.ExchangeQuery\x1a\x19.ctplite.ExchangeResponse\x12\x42\n\rQueryInvestor\x12\x16.ctplite.InvestorQuery\x1a\x19.ctplite.InvestorResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'trading_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DIRECTION']._serialized_start=6226
  _globals['_DIRECTION']._serialized_end=6256
  _globals['_OFFSET']._serialized_start=6258
  _globals['_OFFSET']._serialized_end=6325
  _globals['_ORDERTYPE']._serialized_start=6327
  _globals['_ORDERTYPE']._serialized_end=6379
  _globals['_ORDERSTATUS']._serialized_start=6381
  _globals['_ORDERSTATUS']._serialized_end=6486
  _globals['_ORDERREQUEST']._serialized_start=41
  _globals['_ORDERREQUEST']._serialized_end=268
  _globals['_CANCELREQUEST']._serialized_start=270
  _globals['_CANCELREQUEST']._serialized_end=373
  _globals['_ORDERRESPONSE']._serialized_start=375
  _globals['_ORDERRESPONSE']._serialized_end=428
  _globals['_POSITIONQUERY']._serialized_start=430
  _globals['_POSITIONQUERY']._serialized_end=515
  _globals['_POSITIONDATA']._serialized_start=518
  _globals['_POSITIONDATA']._serialized_end=662
  _globals['_POSITIONRESPONSE']._serialized_start=664
  _globals['_POSITIONRESPONSE']._serialized_end=744
  _globals['_ORDERSTATUSUPDATE']._serialized_start=747
  _globals['_ORDERSTATUSUPDATE']._serialized_end=923
  _globals['_TRADINGACCOUNTQUERY']._serialized_start=925
  _globals['_TRADINGACCOUNTQUERY']._serialized_end=982
  _globals['_TRADINGACCOUNTDATA']._serialized_start=985
  _globals['_TRADINGACCOUNTDATA']._serialized_end=1470
  _globals['_TRADINGACCOUNTRESPONSE']._serialized_start=1472
  _globals['_TRADINGACCOUNTRESPONSE']._serialized_end=1562
  _globals['_ORDERQUERY']._serialized_start=1564
  _globals['_ORDERQUERY']._serialized_end=1668
  _globals['_ORDERDATA']._serialized_start=1671
  _globals['_ORDERDATA']._serialized_end=1982
  _globals['_ORDERQUERYRESPONSE']._serialized_start=1984
  _globals['_ORDERQUERYRESPONSE']._serialized_end=2060
  _globals['_TRADEQUERY']._serialized_start=2062
  _globals['_TRADEQUERY']._serialized_end=2162
  _globals['_TRADEDATA']._serialized_start=2165
  _globals['_TRADEDATA']._serialized_end=2391
  _globals['_TRADEQUERYRESPONSE']._serialized_start=2393
  _globals['_TRADEQUERYRESPONSE']._serialized_end=2469
  _globals['_SETTLEMENTCONFIRMREQUEST']._serialized_start=2471
  _globals['_SETTLEMENTCONFIRMREQUEST']._serialized_end=2533
  _globals['_SETTLEMENTCONFIRMRESPONSE']._serialized_start=2535
  _globals['_SETTLEMENTCONFIRMRESPONSE']._serialized_end=2599
  _globals['_INSTRUMENTQUERY']._serialized_start=2601
  _globals['_INSTRUMENTQUERY']._serialized_end=2688
  _globals['_INSTRUMENTDATA']._serialized_start=2691
  _globals['_INSTRUMENTDATA']._serialized_end=3282
  _globals['_INSTRUMENTQUERYRESPONSE']._serialized_start=3284
  _globals['_INSTRUMENTQUERYRESPONSE']._serialized_end=3375
  _globals['_INSTRUMENTMARGINRATEQUERY']._serialized_start=3377
  _globals['_INSTRUMENTMARGINRATEQUERY']._serialized_end=3494
  _globals['_INSTRUMENTMARGINRATEDATA']._serialized_start=3497
  _globals['_INSTRUMENTMARGINRATEDATA']._serialized_end=3810
  _globals['_INSTRUMENTMARGINRATERESPONSE']._serialized_start=3812
  _globals['_INSTRUMENTMARGINRATERESPONSE']._serialized_end=3919
  _globals['_INSTRUMENTCOMMISSIONRATEQUERY']._serialized_start=3921
  _globals['_INSTRUMENTCOMMISSIONRATEQUERY']._serialized_end=4022
  _globals['_INSTRUMENTCOMMISSIONRATEDATA']._serialized_start=4025
  _globals['_INSTRUMENTCOMMISSIONRATEDATA']._serialized_end=4364
  _globals['_INSTRUMENTCOMMISSIONRATERESPONSE']._serialized_start=4366
  _globals['_INSTRUMENTCOMMISSIONRATERESPONSE']._serialized_end=4485
  _globals['_SETTLEMENTINFOQUERY']._serialized_start=4487
  _globals['_SETTLEMENTINFOQUERY']._serialized_end=4565
  _globals['_SETTLEMENTINFODATA']._serialized_start=4568
  _globals['_SETTLEMENTINFODATA']._serialized_end=4751
  _globals['_SETTLEMENTINFORESPONSE']._serialized_start=4753
  _globals['_SETTLEMENTINFORESPONSE']._serialized_end=4852
  _globals['_TRADINGLOGOUTREQUEST']._serialized_start=4854
  _globals['_TRADINGLOGOUTREQUEST']._serialized_end=4912
  _globals['_TRADINGLOGOUTRESPONSE']._serialized_start=4914
  _globals['_TRADINGLOGOUTRESPONSE']._serialized_end=4974
  _globals['_MAXORDERVOLUMEQUERY']._serialized_start=4977
  _globals['_MAXORDERVOLUMEQUERY']._serialized_end=5160
  _globals['_MAXORDERVOLUMEDATA']._serialized_start=5163
  _globals['_MAXORDERVOLUMEDATA']._serialized_end=5393
  _globals['_MAXORDERVOLUMERESPONSE']._serialized_start=5395
  _globals['_MAXORDERVOLUMERESPONSE']._serialized_end=5494
  _globals['_EXCHANGEQUERY']._serialized_start=5496
  _globals['_EXCHANGEQUERY']._serialized_end=5568
  _globals['_EXCHANGEDATA']._serialized_start=5570
  _globals['_EXCHANGEDATA']._serialized_end=5655
  _globals['_EXCHANGERESPONSE']._serialized_start=5657
  _globals['_EXCHANGERESPONSE']._serialized_end=5737
  _globals['_INVESTORQUERY']._serialized_start=5739
  _globals['_INVESTORQUERY']._serialized_end=5790
  _globals['_INVESTORDATA']._serialized_start=5793
  _globals['_INVESTORDATA']._serialized_end=6143
  _globals['_INVESTORRESPONSE']._serialized_start=6145
  _globals['_INVESTORRESPONSE']._serialized_end=6224
  _globals['_TRADINGSERVICE']._serialized_start=6489
  _globals['_TRADINGSERVICE']._serialized_end=7767
# @@protoc_insertion_point(module_scope)
