# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import market_data_pb2 as market__data__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in market_data_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MarketDataServiceStub(object):
    """行情数据服务
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SubscribeMarketData = channel.unary_stream(
                '/ctplite.MarketDataService/SubscribeMarketData',
                request_serializer=market__data__pb2.SubscribeRequest.SerializeToString,
                response_deserializer=market__data__pb2.MarketDataStream.FromString,
                _registered_method=True)
        self.SubscribeMarketDataOnce = channel.unary_unary(
                '/ctplite.MarketDataService/SubscribeMarketDataOnce',
                request_serializer=market__data__pb2.SubscribeRequest.SerializeToString,
                response_deserializer=market__data__pb2.SubscribeResponse.FromString,
                _registered_method=True)
        self.UnsubscribeMarketData = channel.unary_unary(
                '/ctplite.MarketDataService/UnsubscribeMarketData',
                request_serializer=market__data__pb2.UnsubscribeRequest.SerializeToString,
                response_deserializer=market__data__pb2.UnsubscribeResponse.FromString,
                _registered_method=True)


class MarketDataServiceServicer(object):
    """行情数据服务
    """

    def SubscribeMarketData(self, request, context):
        """订阅行情（流式推送）
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubscribeMarketDataOnce(self, request, context):
        """订阅行情（非流式，仅返回订阅结果）
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnsubscribeMarketData(self, request, context):
        """取消订阅行情（REST订阅使用）
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MarketDataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SubscribeMarketData': grpc.unary_stream_rpc_method_handler(
                    servicer.SubscribeMarketData,
                    request_deserializer=market__data__pb2.SubscribeRequest.FromString,
                    response_serializer=market__data__pb2.MarketDataStream.SerializeToString,
            ),
            'SubscribeMarketDataOnce': grpc.unary_unary_rpc_method_handler(
                    servicer.SubscribeMarketDataOnce,
                    request_deserializer=market__data__pb2.SubscribeRequest.FromString,
                    response_serializer=market__data__pb2.SubscribeResponse.SerializeToString,
            ),
            'UnsubscribeMarketData': grpc.unary_unary_rpc_method_handler(
                    servicer.UnsubscribeMarketData,
                    request_deserializer=market__data__pb2.UnsubscribeRequest.FromString,
                    response_serializer=market__data__pb2.UnsubscribeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ctplite.MarketDataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ctplite.MarketDataService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class MarketDataService(object):
    """行情数据服务
    """

    @staticmethod
    def SubscribeMarketData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/ctplite.MarketDataService/SubscribeMarketData',
            market__data__pb2.SubscribeRequest.SerializeToString,
            market__data__pb2.MarketDataStream.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SubscribeMarketDataOnce(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ctplite.MarketDataService/SubscribeMarketDataOnce',
            market__data__pb2.SubscribeRequest.SerializeToString,
            market__data__pb2.SubscribeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnsubscribeMarketData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ctplite.MarketDataService/UnsubscribeMarketData',
            market__data__pb2.UnsubscribeRequest.SerializeToString,
            market__data__pb2.UnsubscribeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
